# -*- coding: utf-8 -*-

import os
__title__ = 'SWAT-EM - Specific Winding Analyse Tool for electrical machines'
__version__ = '0.1.2'
__author__ = 'Martin Baun'
__license__ = 'GPLv3'
__copyright__ = 'Copyright 2018-2019 Martin Baun'

__dir__ = os.path.dirname(os.path.abspath(__file__))


    
